@@ -141,6 +141,8 @@ class HyperV:
             if 'get_snapshot' in kwargs.keys(): params = f"| Get-VMSnapshot"
             if 'current_snapshot' in kwargs.keys(): params = f"| select Name, ParentSnapshotName"
             if 'dellete_snapshots' in kwargs.keys(): params = f"| Remove-VMSnapshot -Name {kwargs['dellete_snapshots']}"
+            if 'apply_snapshots' in kwargs.keys(): params = f"| Restore-VMSnapshot -Name  {kwargs['apply_snapshots']} -Confirm:$false"
+
         all_vms = f"{self.env_prefix}* "
 
         if vms_list:
@@ -151,56 +153,63 @@ class HyperV:
         logging.debug(f'ps_script: {ps_script}')
         return ps_script
     
-    class snapshot:
-        # Создать снапшот машин по маске или передав список машин
-        def create(self, snapshot_name='Clear_OS', vms=[]):
-            ps_script = self.gen_job(vms_list=vms, job='Checkpoint-VM', create_snapshot = snapshot_name)
-            logging.debug(f'ps_script \n{ps_script}')
-            result = self.session.run_ps(ps_script)
-            logging.debug(f"result std_out\n{result.std_out.decode('utf-8')}")
-            logging.debug(f"result status_code \n{result.status_code}")
-            if result.status_code == '1':
-                return False
-            return True
+    # Создать снапшот машин по маске или передав список машин
+    def snapshot_create(self, snapshot_name='Clear_OS', vms=[]):
+        ps_script = self.gen_job(vms_list=vms, job='Checkpoint-VM', create_snapshot = snapshot_name)
+        logging.debug(f'ps_script \n{ps_script}')
+        result = self.session.run_ps(ps_script)
+        logging.debug(f"result std_out\n{result.std_out.decode('utf-8')}")
+        logging.debug(f"result status_code \n{result.status_code}")
+        if result.status_code == '1':
+            return False
+        return True
+    
+    # Список снапшотов фиртуалных машин 
+    def snapshot_get_all(self, vms=[]):
+        ps_script = self.gen_job(vms_list=vms, job='Get-VM', get_snapshot = True)
+        result = self.session.run_ps(ps_script)
+        logging.debug(f"result std_out: {result.std_out.decode('utf-8')}")
+        logging.debug(f"result status_code \n{result.status_code}")
+        if result.status_code == '1':
+            return False
         
-        # Список снапшотов фиртуалных машин 
-        def get_all(self, vms=[]):
-            ps_script = self.gen_job(vms_list=vms, job='Get-VM', get_snapshot = True)
-            result = self.session.run_ps(ps_script)
-            logging.debug(f"result std_out: {result.std_out.decode('utf-8')}")
-            logging.debug(f"result status_code \n{result.status_code}")
-            if result.status_code == '1':
-                return False
-            
-            r_result = {}
-            for line in result.std_out.decode('utf-8').splitlines():
-                if line and not 'VMName' in line and not '------' in line:
-                    r_result.setdefault(line.split()[0], []).append(line.split()[1:])
-            return r_result
-
-        # Получить текущие снапшоты виртуальных машин
-        def get_current(self, vms=[]):
-            ps_script = self.gen_job(vms_list=vms, job='Get-VM', current_snapshot = True)
-            result = self.session.run_ps(ps_script)
-            logging.debug(f"result std_out: {result.std_out.decode('utf-8')}")
-            logging.debug(f"result status_code \n{result.status_code}")
-            if result.status_code == '1':
-                return False
-            r_result = {}
-            for line in result.std_out.decode('utf-8').splitlines():
-                if line and not 'Name' in line and not '----' in line:
-                    r_result.setdefault(line.split()[0],line.split()[1:][0])
-            return r_result
-        
-        # Удалить снапшоты
-        def rm(self, vms=[], snapshot_name=''):
-            ps_script = self.gen_job(vms_list=vms, job='Get-VM', dellete_snapshots = snapshot_name)
-            result = self.session.run_ps(ps_script)
-            logging.debug(f"result std_out: {result.std_out.decode('utf-8')}")
-            logging.debug(f"result status_code: {result.status_code}")
-            if result.status_code == '1':
-                return False
-            return True
+        r_result = {}
+        for line in result.std_out.decode('utf-8').splitlines():
+            if line and not 'VMName' in line and not '------' in line:
+                r_result.setdefault(line.split()[0], []).append(line.split()[1:])
+        return r_result
 
+    # Получить текущие снапшоты виртуальных машин
+    def snapshot_get_current(self, vms=[]):
+        ps_script = self.gen_job(vms_list=vms, job='Get-VM', current_snapshot = True)
+        result = self.session.run_ps(ps_script)
+        logging.debug(f"result std_out: {result.std_out.decode('utf-8')}")
+        logging.debug(f"result status_code \n{result.status_code}")
+        if result.status_code == '1':
+            return False
+        r_result = {}
+        for line in result.std_out.decode('utf-8').splitlines():
+            if line and not 'Name' in line and not '----' in line:
+                r_result.setdefault(line.split()[0],line.split()[1:][0])
+        return r_result
+    
+    # Удалить снапшоты
+    def snapshot_rm(self, vms=[], snapshot_name=''):
+        ps_script = self.gen_job(vms_list=vms, job='Get-VM', dellete_snapshots = snapshot_name)
+        result = self.session.run_ps(ps_script)
+        logging.debug(f"result std_out: {result.std_out.decode('utf-8')}")
+        logging.debug(f"result status_code: {result.status_code}")
+        if result.status_code == '1':
+            return False
+        return True
+
+    def snapshot_apply(self, vms=[], snapshot_name=''):
+        ps_script = self.gen_job(vms_list=vms, job='Get-VM', apply_snapshots = snapshot_name)
+        result = self.session.run_ps(ps_script)
+        logging.debug(f"result std_out: {result.std_out.decode('utf-8')}")
+        logging.debug(f"result status_code: {result.status_code}")
+        if result.status_code == '1':
+            return False
+        return True
 
 
